@@ -1,6 +1,6 @@
 package Tapper::Cmd::Testrun;
 our $AUTHORITY = 'cpan:TAPPER';
-$Tapper::Cmd::Testrun::VERSION = '5.0.12';
+$Tapper::Cmd::Testrun::VERSION = '5.0.13';
 use Moose;
 use Tapper::Model 'model';
 use DateTime;
@@ -48,7 +48,7 @@ sub create
             ->add(\@plan_preconditions)
         ;
 
-        my %args          = map { lc($_) => $plan->{$_} } grep { lc($_) ne 'preconditions' and $_ !~ /^requested/i } keys %$plan;
+        my %args          = map { lc($_) => $plan->{$_} } grep { lc($_) ne 'preconditions' and $_ !~ /^requested_(hosts|features)/i } keys %$plan;
 
         my @testruns;
         foreach my $host (@{$plan->{requested_hosts_all} || [] }) {
@@ -84,7 +84,7 @@ sub create
                 $self->assign_preconditions($testrun_id, @preconditions);
                 push @testruns, $testrun_id;
         }
-        if ( not grep { $_ =~ /^requested/i } keys %$plan) {
+        if ( not grep { $_ =~ /^requested_(hosts|features)/i } keys %$plan) {
                 my $merged_arguments = merge \%args, {precondition    => \@plan_preconditions,
                                                       testplan_id     => $instance,
                                                      };
@@ -155,6 +155,13 @@ sub add {
                                 }
                         }
 
+                        if ( $args{requested_resources} ) {
+                                my $testrun = $or_schema->resultset('Testrun')->find($testrun_id);
+                                foreach my $request (@{$args{requested_resources}}) {
+                                        $testrun->add_requested_resource_by_name( ref($request) eq "ARRAY" ? @$request : ($request) );
+                                }
+                        }
+
                         if ( exists $args{notify} ) {
                                 my $s_notify = $args{notify} // q##;
                                 my $notify   = Tapper::Cmd::Notification->new();
@@ -517,7 +524,7 @@ Tapper Team <tapper-ops@amazon.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2020 by Advanced Micro Devices, Inc.
+This software is Copyright (c) 2022 by Advanced Micro Devices, Inc.
 
 This is free software, licensed under:
 
